@@ -1,29 +1,31 @@
-/* alarms.c -- draw the point and click interface of TuxTime
+/* alarms.c -- draw the alarm settings dialog of TuxTime Configuration Manager
  *
  * Copyright (c) 1996-99  Jonathan A. Buzzard (jonathan@buzzard.org.uk)
  *
  * $Log: alarms.c,v $
+ * Revision 1.2  1999/12/04 13:44:04  jab
+ * changed for the new tuxtime-conf program
+ *
  * Revision 1.1  1999/05/25 08:06:37  jab
  * Initial revision
  *
- *
- * This program is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by the
- * Free Software Foundation; either version 2, or (at your option) any
- * later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 675 Mass Ave, Cambridge, MA 02139, USA.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software 
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
  */
 
-static const char rcsid[]="$Id: alarms.c,v 1.1 1999/05/25 08:06:37 jab Exp jab $";
+static const char rcsid[]="$Id: alarms.c,v 1.2 1999/12/04 13:44:04 jab Exp jab $";
 
 
 #include<stdio.h>
@@ -34,7 +36,6 @@ static const char rcsid[]="$Id: alarms.c,v 1.1 1999/05/25 08:06:37 jab Exp jab $
 #include"misc.h"
 #include"config.h"
 #include"alarms.h"
-#include"update.h"
 
 #include"plus.xpm"
 #include"minus.xpm"
@@ -329,9 +330,10 @@ void SaveAlarmSettingsCallback(GtkWidget *widget, gpointer *data)
 	sprintf(buffer, "%d", critical.trigger);
 	WriteConfigString("AlarmCritical", "Trigger", buffer, config);
 
-	SetupAlarms();
 	gtk_widget_destroy(GTK_WIDGET(data));
 
+	ExitTuxTimeConfig(0x10);
+
 	return;
 }
 
@@ -377,6 +379,7 @@ void SetAlarmDefaultsCallback(GtkWidget *widget, gpointer *data)
 
 /*
  * Quit the alarms dialog without changing the settings
+
  */
 void AlarmCancelCallback(GtkWidget *widget, GtkWidget *dialog)
 {
@@ -387,6 +390,8 @@ void AlarmCancelCallback(GtkWidget *widget, GtkWidget *dialog)
 	gdk_bitmap_unref(plusmask);
 	gdk_pixmap_unref(minuspixmap);
 	gdk_bitmap_unref(minusmask);
+
+	ExitTuxTimeConfig(0);
 	
 	return;
 }
@@ -394,7 +399,6 @@ void AlarmCancelCallback(GtkWidget *widget, GtkWidget *dialog)
 
 /*
  * Build the Alarm Setting pages of the notebook
- *
  */
 void AddAlarmPage(GtkNotebook *notebook, GtkWidget *window, int type)
 {
@@ -644,49 +648,34 @@ void AddAlarmPage(GtkNotebook *notebook, GtkWidget *window, int type)
 /*
  * Build the alarms setting dialog
  */
-void AlarmDialog(void)
+void AlarmDialog(GtkWidget *window)
 {
-	static GtkWidget *window = NULL;
 	GtkWidget *notebook;
 	GdkColor *transparent = NULL;
 
-	if (!window) {
-		window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 
-		gtk_signal_connect(GTK_OBJECT(window), "destroy",
-			GTK_SIGNAL_FUNC(gtk_widget_destroyed), &window);
+	/* create a new notebook, place the position of the tabs */
 
-		gtk_window_set_title(GTK_WINDOW(window), "Alarms");
-		gtk_container_border_width(GTK_CONTAINER(window), 6);
+	notebook = gtk_notebook_new();
+	gtk_notebook_set_tab_pos(GTK_NOTEBOOK(notebook), GTK_POS_TOP);
+	gtk_container_add(GTK_CONTAINER(window), notebook);
 
-		/* create a new notebook, place the position of the tabs */
+	/* create the pixmaps used by the dialog */
 
-		notebook = gtk_notebook_new();
-		gtk_notebook_set_tab_pos(GTK_NOTEBOOK(notebook), GTK_POS_TOP);
-		gtk_container_add(GTK_CONTAINER(window), notebook);
-		gtk_widget_realize(notebook);
+	pluspixmap = gdk_pixmap_create_from_xpm_d(window->window,
+		&plusmask, transparent, plus_xpm);
+	minuspixmap = gdk_pixmap_create_from_xpm_d(window->window,
+		&minusmask, transparent, minus_xpm);
 
-		/* create the pixmaps used by the dialog */
 
-		pluspixmap = gdk_pixmap_create_from_xpm_d(notebook->window,
-			&plusmask, transparent, plus_xpm);
-		minuspixmap = gdk_pixmap_create_from_xpm_d(notebook->window,
-			&minusmask, transparent, minus_xpm);
+	/* add the two pages to the notebook */
 
-		/* add the two pages to the notebook */
+	AddAlarmPage(GTK_NOTEBOOK(notebook), window, LOW_ALARM);
+	AddAlarmPage(GTK_NOTEBOOK(notebook), window, CRITICAL_ALARM);
 
-		AddAlarmPage(GTK_NOTEBOOK(notebook), window, LOW_ALARM);
-		AddAlarmPage(GTK_NOTEBOOK(notebook), window, CRITICAL_ALARM);
+	/* set to start at first page */
 
-		/* set to start at first page */
-
-		gtk_notebook_set_page(GTK_NOTEBOOK(notebook), 0);
-	}
-
-	if (!GTK_WIDGET_VISIBLE(window))
-		gtk_widget_show_all(window);
-	else
-		gtk_widget_destroy(window);
+	gtk_notebook_set_page(GTK_NOTEBOOK(notebook), 0);
 
 	return;
 }
